@@ -1,6 +1,6 @@
 package Map::Tube::CLI;
 
-$Map::Tube::CLI::VERSION   = '0.53';
+$Map::Tube::CLI::VERSION   = '0.54';
 $Map::Tube::CLI::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ Map::Tube::CLI - Command Line Interface for Map::Tube::* map.
 
 =head1 VERSION
 
-Version 0.53
+Version 0.54
 
 =cut
 
@@ -49,19 +49,20 @@ You can list all command line options by giving C<-h> flag.
     $ map-tube -h
     USAGE: map-tube [-h] [long options...]
 
-        --map=String     Map name
-        --start=String   Start station name
-        --end=String     End station name
-        --preferred      Show preferred route
-        --generate_map   Generate map as image
-        --line=String    Line name for map
-        --line_mappings  Generate line mappings
-        --line_notes     Generate line notes
+        --map=String      Map name
+        --start=String    Start station name
+        --end=String      End station name
+        --preferred       Show preferred route
+        --generate_map    Generate map as image
+        --line=String     Line name for map
+        --bgcolor=String  Map background color
+        --line_mappings   Generate line mappings
+        --line_notes      Generate line notes
 
-        --usage          show a short help message
-        -h               show a compact help message
-        --help           show a long help message
-        --man            show the manual
+        --usage           show a short help message
+        -h                show a compact help message
+        --help            show a long help message
+        --man             show the manual
 
 =head1 COMMON USAGES
 
@@ -69,7 +70,7 @@ You can list all command line options by giving C<-h> flag.
 
 You can also ask for shortest route in London Tube Map as below:
 
-    $ map-tube --map 'London' --start 'Baker Street' --end 'Wembley Park'
+    $ map-tube --map London --start 'Baker Street' --end 'Wembley Park'
 
     Baker Street (Bakerloo, Circle, Hammersmith & City, Jubilee, Metropolitan), Finchley Road (Jubilee, Metropolitan), Wembley Park (Jubilee, Metropolitan)
 
@@ -77,7 +78,7 @@ You can also ask for shortest route in London Tube Map as below:
 
 Now request for preferred route as below:
 
-    $ map-tube --map 'London' --start 'Baker Street' --end 'Euston Square' --preferred
+    $ map-tube --map London --start 'Baker Street' --end 'Euston Square' --preferred
 
     Baker Street (Circle, Hammersmith & City, Metropolitan), Great Portland Street (Circle, Hammersmith & City, Metropolitan), Euston Square (Circle, Hammersmith & City, Metropolitan)
 
@@ -85,31 +86,39 @@ Now request for preferred route as below:
 
 To generate entire map, follow the command below:
 
-    $ map-tube --map 'Delhi' --generate_map
+    $ map-tube --map Delhi --generate_map
+
+In case you want different background color to the map then you can try below:
+
+    $ map-tube --map Delhi --bgcolor gray --generate_map
 
 =head2 Generate Just a Line Map
 
 To generate just a particular line map, follow the command below:
 
-    $ map-tube --map 'London' --line 'Bakerloo' --generate_map
+    $ map-tube --map London --line Bakerloo --generate_map
+
+In case you want different background color to the map then you can try below:
+
+    $ map-tube --map London --line DLR --bgcolor yellow --generate_map
 
 =head2 Generate Line Mappings
 
-    $ map-tube --map 'London' --line 'Bakerloo' --line_mappings
+    $ map-tube --map London --line Bakerloo --line_mappings
 
 =head2 Generate Line Notes
 
-    $ map-tube --map 'London' --line 'Bakerloo' --line_notes
+    $ map-tube --map London --line Bakerloo --line_notes
 
 =head2 General Error
 
 If encountered  invalid  map  or  missing map i.e not installed, you get an error
 message like below:
 
-    $ map-tube --map 'xYz' --start 'Baker Street' --end 'Euston Square'
+    $ map-tube --map xYz --start 'Baker Street' --end 'Euston Square'
     ERROR: Unsupported Map [xYz].
 
-    $ map-tube --map 'Kazan' --start 'Baker Street' --end 'Euston Square'
+    $ map-tube --map Kazan --start 'Baker Street' --end 'Euston Square'
     ERROR: Missing Map [Kazan].
 
 =head1 SUPPORTED MAPS
